CatalogError

Enum CatalogError 

#[non_exhaustive]
pub enum CatalogError {
Show 27 variants InvalidJobType { job_type: String, source: IdentifierValidationError, }, InvalidHandlerJobType { handler_job_type: String, source: IdentifierValidationError, }, HandlerJobTypeMismatch { declared: String, handler: String, }, DuplicateJobType { job_type: String, }, InvalidDefinitionValue { field: &'static str, }, InvalidFailureCode, InvalidRetryDelay, InvalidExactSyncScope, InvalidExactSyncScopeJobType { job_type: String, source: IdentifierValidationError, }, EmptyExactSyncCatalog, JobTypeOutsideExactSyncScope { job_type: String, }, ActiveScheduleForAbsentJobType { schedule_name: String, job_type: String, }, ActiveScheduleForDisabledJobType { schedule_name: String, job_type: String, }, UnknownJobType { job_type: String, }, DisabledJobType { job_type: String, }, WorkflowBuild(WorkflowBuildError), SyncFailure(Error), DefinitionCatalogSyncFailure(Box<dyn Error + Send + Sync>), DefinitionSyncFailure { job_type: String, source: Error, }, CommitFailure(Error), CriticalSectionTimeoutFailure(Error), DefinitionSyncValidationFailure(Error), ScheduleLockFailure(Error), DefinitionLockFailure(Error), ScheduleCheckFailure(Error), DefinitionInspectFailure(Error), DisableAbsentFailure(Error),
}
Error returned by super::JobCatalog validation, sync, and helper methods.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidJobType

A caller supplied an invalid catalog job type.

Fields

job_type: String

Invalid job type value supplied by the caller.

source: IdentifierValidationError

Identifier validation failure reported by runledger-core.



InvalidHandlerJobType

A registered handler returned an invalid job type.

Fields

handler_job_type: String

Invalid job type returned by the handler.

source: IdentifierValidationError

Identifier validation failure reported by runledger-core.



HandlerJobTypeMismatch

The declared catalog job type did not match the handler’s job type.

Fields

declared: String

Job type declared at the catalog registration site.

handler: String

Job type returned by the handler.



DuplicateJobType

The catalog already contains the requested job type.

Fields

job_type: String

Duplicate job type.



InvalidDefinitionValue

A catalog definition default failed validation.

Fields

field: &'static str

Name of the invalid defaults field.



InvalidFailureCode

Retry-delay override failure codes must be non-empty.



InvalidRetryDelay

Retry-delay override values must be positive.



InvalidExactSyncScope

Exact sync requires a non-empty owned job-type scope.



InvalidExactSyncScopeJobType

Exact sync scope construction received an invalid job type.

Fields

job_type: String

Invalid job type supplied for the exact-sync scope.

source: IdentifierValidationError

Identifier validation failure reported by runledger-core.



EmptyExactSyncCatalog

Exact sync cannot run against an empty catalog.



JobTypeOutsideExactSyncScope

A catalog job was not included in the exact-sync scope.

Fields

job_type: String

Catalog job type missing from the exact-sync scope.



ActiveScheduleForAbsentJobType

An active schedule still references an enabled definition absent from the catalog.

Fields

schedule_name: String

Active schedule name that blocks disabling the absent definition.

job_type: String

Absent catalog job type referenced by the active schedule.



ActiveScheduleForDisabledJobType

An active schedule still references a catalog job that would be disabled.

Fields

schedule_name: String

Active schedule name that blocks disabling the catalog definition.

job_type: String

Catalog job type referenced by the active schedule.



UnknownJobType

The requested job type is not registered in the catalog.

Fields

job_type: String

Missing job type.



DisabledJobType

The requested job type is disabled in catalog defaults.

Fields

job_type: String

Disabled job type.



WorkflowBuild(WorkflowBuildError)

Workflow enqueue construction failed.



SyncFailure(Error)

Starting a catalog sync transaction failed.



DefinitionCatalogSyncFailure(Box<dyn Error + Send + Sync>)

A persistence-layer catalog sync failure had no runtime-specific mapping.



DefinitionSyncFailure

Syncing a specific catalog job definition failed.

Fields

job_type: String

Catalog job type whose definition failed to sync.

source: Error

Persistence-layer failure that occurred while syncing the definition.



CommitFailure(Error)

Committing a catalog sync transaction failed.



CriticalSectionTimeoutFailure(Error)

Applying the transaction-local bounds for definition-disabling sync failed.



DefinitionSyncValidationFailure(Error)

Catalog definition sync input failed persistence-layer validation.



ScheduleLockFailure(Error)

Locking schedules before disabling definitions failed.



DefinitionLockFailure(Error)

Locking definitions before checking and disabling definitions failed.



ScheduleCheckFailure(Error)

Checking active schedules before disabling definitions failed.



DefinitionInspectFailure(Error)

Inspecting existing job definitions before sync failed.



DisableAbsentFailure(Error)

Disabling absent job definitions failed.