#[non_exhaustive]pub struct JobCatalogDefinitionOverrides { /* private fields */ }Expand description
Per-job definition values that override JobCatalogDefaults.
Implementations
Sourceimpl JobCatalogDefinitionOverrides
impl JobCatalogDefinitionOverrides
Sourcepub fn version(self, version: i32) -> Self
pub fn version(self, version: i32) -> Self
Overrides the definition version written for this job.
Sourcepub fn max_attempts(self, max_attempts: i32) -> Self
pub fn max_attempts(self, max_attempts: i32) -> Self
Overrides the default maximum attempts written for this job.
Sourcepub fn timeout_seconds(self, default_timeout_seconds: i32) -> Self
pub fn timeout_seconds(self, default_timeout_seconds: i32) -> Self
Overrides the default execution timeout, in seconds, written for this job.