JobCatalogExactSyncReport

Struct JobCatalogExactSyncReport 

#[non_exhaustive]
pub struct JobCatalogExactSyncReport { pub disabled_absent_job_types: Vec<JobTypeName>, pub disabled_catalog_job_types: Vec<JobTypeName>, }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
disabled_absent_job_types: Vec<JobTypeName>

Enabled definitions inside the exact-sync scope that were absent from the catalog and changed to disabled by this sync.

disabled_catalog_job_types: Vec<JobTypeName>

Catalog job types that this sync forced disabled through catalog defaults, including both newly inserted disabled rows and existing enabled rows changed to disabled. Already-disabled catalog rows are not included.