#[non_exhaustive]pub struct JobCatalogScheduleSyncReport {
pub synced_schedule_names: Vec<String>,
pub deactivated_absent_schedule_names: Vec<String>,
}Expand description
Result returned by catalog schedule sync methods.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.synced_schedule_names: Vec<String>Schedule names upserted and active state applied during this sync, in the order they were supplied by the catalog or caller.
deactivated_absent_schedule_names: Vec<String>Enabled schedules inside the exact-sync scope that were absent from the synced spec set and changed to inactive by this sync. Empty for additive sync methods. Names are returned in sorted order.