pub struct SupervisorShutdown { /* private fields */ }Expand description
Cloneable handle for requesting supervisor shutdown from another task.
Implementations
Sourceimpl SupervisorShutdown
impl SupervisorShutdown
Sourcepub fn request_shutdown(&self)
pub fn request_shutdown(&self)
Requests graceful shutdown of all loops watched by the supervisor.
Sourcepub fn is_shutdown_requested(&self) -> bool
pub fn is_shutdown_requested(&self) -> bool
Returns whether shutdown has been requested.