CatalogError

Enum CatalogError 

#[non_exhaustive]
pub enum CatalogError {
Show 40 variants InvalidJobType { job_type: String, source: IdentifierValidationError, }, InvalidHandlerJobType { handler_job_type: String, source: IdentifierValidationError, }, HandlerJobTypeMismatch { declared: String, handler: String, }, DuplicateJobType { job_type: String, }, InvalidDefinitionValue { field: &'static str, }, InvalidJobDefinitionValue { job_type: String, field: &'static str, }, InvalidFailureCode, InvalidRetryDelay, InvalidExactSyncScope, InvalidExactSyncScopeJobType { job_type: String, source: IdentifierValidationError, }, EmptyExactSyncCatalog, JobTypeOutsideExactSyncScope { job_type: String, }, ActiveScheduleForAbsentJobType { schedule_name: String, job_type: String, }, ActiveScheduleForDisabledJobType { schedule_name: String, job_type: String, }, UnknownJobType { job_type: String, }, DisabledJobType { job_type: String, }, WorkflowBuild(WorkflowBuildError), SyncFailure(Box<Error>), DefinitionCatalogSyncFailure(Box<dyn Error + Send + Sync>), DefinitionSyncFailure { job_type: String, source: Box<Error>, }, CommitFailure(Error), CriticalSectionTimeoutFailure(Box<Error>), DefinitionSyncValidationFailure(Box<Error>), ScheduleLockFailure(Box<Error>), DefinitionLockFailure(Box<Error>), ScheduleCheckFailure(Box<Error>), DefinitionInspectFailure(Box<Error>), DisableAbsentFailure(Box<Error>), InvalidExactScheduleSyncScope, InvalidExactScheduleSyncScopeName { name: String, }, DuplicateExactScheduleSyncScopeName { name: String, }, ScheduleNameOutsideExactSyncScope { name: String, }, DuplicateScheduleName { name: String, }, InvalidScheduleSpec { name: String, field: &'static str, }, DuplicateScheduleNameInSyncBatch { name: String, }, ScheduleSyncFailure(Box<Error>), ScheduleSyncCriticalSectionFailure(Box<Error>), ScheduleSyncEntryFailure { name: String, source: Box<Error>, }, DeactivateAbsentSchedulesFailure(Box<Error>), ScheduleSyncCommitFailure(Box<Error>),
}
Error returned by super::JobCatalog validation, sync, and helper methods.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidJobType

A caller supplied an invalid catalog job type.

Fields

job_type: String

Invalid job type value supplied by the caller.

source: IdentifierValidationError

Identifier validation failure reported by runledger-core.



InvalidHandlerJobType

A registered handler returned an invalid job type.

Fields

handler_job_type: String

Invalid job type returned by the handler.

source: IdentifierValidationError

Identifier validation failure reported by runledger-core.



HandlerJobTypeMismatch

The declared catalog job type did not match the handler’s job type.

Fields

declared: String

Job type declared at the catalog registration site.

handler: String

Job type returned by the handler.



DuplicateJobType

The catalog already contains the requested job type.

Fields

job_type: String

Duplicate job type.



InvalidDefinitionValue

A catalog definition default failed validation.

Fields

field: &'static str

Name of the invalid defaults field.



InvalidJobDefinitionValue

A job-specific catalog definition override failed validation.

Fields

job_type: String

Job type whose effective definition values are invalid.

field: &'static str

Name of the invalid definition field.



InvalidFailureCode

Retry-delay override failure codes must be non-empty.



InvalidRetryDelay

Retry-delay override values must be positive.



InvalidExactSyncScope

Exact sync requires a non-empty owned job-type scope.



InvalidExactSyncScopeJobType

Exact sync scope construction received an invalid job type.

Fields

job_type: String

Invalid job type supplied for the exact-sync scope.

source: IdentifierValidationError

Identifier validation failure reported by runledger-core.



EmptyExactSyncCatalog

Exact sync cannot run against an empty catalog.



JobTypeOutsideExactSyncScope

A catalog job was not included in the exact-sync scope.

Fields

job_type: String

Catalog job type missing from the exact-sync scope.



ActiveScheduleForAbsentJobType

An active schedule still references an enabled definition absent from the catalog.

Fields

schedule_name: String

Active schedule name that blocks disabling the absent definition.

job_type: String

Absent catalog job type referenced by the active schedule.



ActiveScheduleForDisabledJobType

An active schedule still references a catalog job that would be disabled.

Fields

schedule_name: String

Active schedule name that blocks disabling the catalog definition.

job_type: String

Catalog job type referenced by the active schedule.



UnknownJobType

The requested job type is not registered in the catalog.

Fields

job_type: String

Missing job type.



DisabledJobType

The requested job type is disabled by effective catalog definition values.

Fields

job_type: String

Disabled job type.



WorkflowBuild(WorkflowBuildError)

Workflow enqueue construction failed.



SyncFailure(Box<Error>)

Starting a catalog sync transaction failed.



DefinitionCatalogSyncFailure(Box<dyn Error + Send + Sync>)

A persistence-layer catalog sync failure had no runtime-specific mapping.



DefinitionSyncFailure

Syncing a specific catalog job definition failed.

Fields

job_type: String

Catalog job type whose definition failed to sync.

source: Box<Error>

Persistence-layer failure that occurred while syncing the definition.



CommitFailure(Error)

Committing a catalog sync transaction failed.



CriticalSectionTimeoutFailure(Box<Error>)

Applying the transaction-local bounds for definition-disabling sync failed.



DefinitionSyncValidationFailure(Box<Error>)

Catalog definition sync input failed persistence-layer validation.



ScheduleLockFailure(Box<Error>)

Locking schedules before disabling definitions failed.



DefinitionLockFailure(Box<Error>)

Locking definitions before checking and disabling definitions failed.



ScheduleCheckFailure(Box<Error>)

Checking active schedules before disabling definitions failed.



DefinitionInspectFailure(Box<Error>)

Inspecting existing job definitions before sync failed.



DisableAbsentFailure(Box<Error>)

Disabling absent job definitions failed.



InvalidExactScheduleSyncScope

Exact schedule sync requires a non-empty owned schedule-name scope.



InvalidExactScheduleSyncScopeName

Exact schedule sync scope construction received an invalid schedule name.

Fields

name: String

Invalid schedule name supplied for the exact-sync scope.



DuplicateExactScheduleSyncScopeName

Exact schedule sync scope construction received a duplicate schedule name.

Fields

name: String

Duplicate schedule name supplied for the exact-sync scope.



ScheduleNameOutsideExactSyncScope

A catalog schedule was not included in the exact-sync scope.

Fields

name: String

Catalog schedule name missing from the exact-sync scope.



DuplicateScheduleName

The catalog already contains the requested schedule name.

Fields

name: String

Duplicate schedule name.



InvalidScheduleSpec

A catalog schedule spec failed validation.

Fields

name: String

Schedule name from the invalid spec.

field: &'static str

Name of the invalid schedule field.



DuplicateScheduleNameInSyncBatch

Duplicate schedule names were supplied in one sync batch.

Fields

name: String

Duplicate schedule name in the sync batch.



ScheduleSyncFailure(Box<Error>)

Starting a catalog schedule sync transaction failed.



ScheduleSyncCriticalSectionFailure(Box<Error>)

Applying the transaction-local bounds for exact schedule sync failed.



ScheduleSyncEntryFailure

Syncing a specific catalog schedule failed.

Fields

name: String

Schedule name whose sync failed.

source: Box<Error>

Persistence-layer failure that occurred while syncing the schedule.



DeactivateAbsentSchedulesFailure(Box<Error>)

Deactivating absent catalog schedules failed.



ScheduleSyncCommitFailure(Box<Error>)

Committing a catalog schedule sync transaction failed.